==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkTransform.java <==
// java wrapper for vtkTransform object
//

package vtk;
import vtk.*;

public class vtkTransform extends vtkLinearTransform
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Identity_2();
  public void Identity()
    { Identity_2(); }

  private native void Inverse_3();
  public void Inverse()
    { Inverse_3(); }

  private native void Translate_4(double id0,double id1,double id2);
  public void Translate(double id0,double id1,double id2)
    { Translate_4(id0,id1,id2); }

  private native void Translate_5(double id0[]);
  public void Translate(double id0[])
    { Translate_5(id0); }

  private native void RotateWXYZ_6(double id0,double id1,double id2,double id3);
  public void RotateWXYZ(double id0,double id1,double id2,double id3)
    { RotateWXYZ_6(id0,id1,id2,id3); }

  private native void RotateWXYZ_7(double id0,double id1[]);
  public void RotateWXYZ(double id0,double id1[])
    { RotateWXYZ_7(id0,id1); }

  private native void RotateX_8(double id0);
  public void RotateX(double id0)
    { RotateX_8(id0); }

  private native void RotateY_9(double id0);
  public void RotateY(double id0)
    { RotateY_9(id0); }

  private native void RotateZ_10(double id0);
  public void RotateZ(double id0)
    { RotateZ_10(id0); }

  private native void Scale_11(double id0,double id1,double id2);
  public void Scale(double id0,double id1,double id2)
    { Scale_11(id0,id1,id2); }

  private native void Scale_12(double id0[]);
  public void Scale(double id0[])
    { Scale_12(id0); }

  private native void SetMatrix_13(vtkMatrix4x4 id0);
  public void SetMatrix(vtkMatrix4x4 id0)
    { SetMatrix_13(id0); }

  private native void SetMatrix_14(double id0[]);
  public void SetMatrix(double id0[])
    { SetMatrix_14(id0); }

  private native void Concatenate_15(vtkMatrix4x4 id0);
  public void Concatenate(vtkMatrix4x4 id0)
    { Concatenate_15(id0); }

  private native void Concatenate_16(double id0[]);
  public void Concatenate(double id0[])
    { Concatenate_16(id0); }

  private native void Concatenate_17(vtkLinearTransform id0);
  public void Concatenate(vtkLinearTransform id0)
    { Concatenate_17(id0); }

  private native void PreMultiply_18();
  public void PreMultiply()
    { PreMultiply_18(); }

  private native void PostMultiply_19();
  public void PostMultiply()
    { PostMultiply_19(); }

  private native int GetNumberOfConcatenatedTransforms_20();
  public int GetNumberOfConcatenatedTransforms()
    { return GetNumberOfConcatenatedTransforms_20(); }

  private native long GetConcatenatedTransform_21(int id0);
  public vtkLinearTransform GetConcatenatedTransform(int id0) {
    long temp = GetConcatenatedTransform_21(id0);

    if (temp == 0) return null;
    return (vtkLinearTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetOrientation_22(double id0[]);
  public void GetOrientation(double id0[])
    { GetOrientation_22(id0); }

  private native double[] GetOrientation_23();
  public double[] GetOrientation()
    { return GetOrientation_23(); }

  private native void GetOrientation_24(double id0[],vtkMatrix4x4 id1);
  public void GetOrientation(double id0[],vtkMatrix4x4 id1)
    { GetOrientation_24(id0,id1); }

  private native void GetOrientationWXYZ_25(double id0[]);
  public void GetOrientationWXYZ(double id0[])
    { GetOrientationWXYZ_25(id0); }

  private native double[] GetOrientationWXYZ_26();
  public double[] GetOrientationWXYZ()
    { return GetOrientationWXYZ_26(); }

  private native void GetPosition_27(double id0[]);
  public void GetPosition(double id0[])
    { GetPosition_27(id0); }

  private native double[] GetPosition_28();
  public double[] GetPosition()
    { return GetPosition_28(); }

  private native void GetScale_29(double id0[]);
  public void GetScale(double id0[])
    { GetScale_29(id0); }

  private native double[] GetScale_30();
  public double[] GetScale()
    { return GetScale_30(); }

  private native void GetInverse_31(vtkMatrix4x4 id0);
  public void GetInverse(vtkMatrix4x4 id0)
    { GetInverse_31(id0); }

  private native void GetTranspose_32(vtkMatrix4x4 id0);
  public void GetTranspose(vtkMatrix4x4 id0)
    { GetTranspose_32(id0); }

  private native void SetInput_33(vtkLinearTransform id0);
  public void SetInput(vtkLinearTransform id0)
    { SetInput_33(id0); }

  private native long GetInput_34();
  public vtkLinearTransform GetInput() {
    long temp = GetInput_34();

    if (temp == 0) return null;
    return (vtkLinearTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetInverseFlag_35();
  public int GetInverseFlag()
    { return GetInverseFlag_35(); }

  private native void Push_36();
  public void Push()
    { Push_36(); }

  private native void Pop_37();
  public void Pop()
    { Pop_37(); }

  private native int CircuitCheck_38(vtkAbstractTransform id0);
  public int CircuitCheck(vtkAbstractTransform id0)
    { return CircuitCheck_38(id0); }

  private native long GetInverse_39();
  public vtkAbstractTransform GetInverse() {
    long temp = GetInverse_39();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MakeTransform_40();
  public vtkAbstractTransform MakeTransform() {
    long temp = MakeTransform_40();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_41();
  public int GetMTime()
    { return GetMTime_41(); }

  private native void MultiplyPoint_42(double id0[],double id1[]);
  public void MultiplyPoint(double id0[],double id1[])
    { MultiplyPoint_42(id0,id1); }

  public vtkTransform() { super(); }

  public vtkTransform(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv7h.pkg.tar.xz: vtk/vtkTransform.java <==
// java wrapper for vtkTransform object
//

package vtk;
import vtk.*;

public class vtkTransform extends vtkLinearTransform
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Identity_2();
  public void Identity()
    { Identity_2(); }

  private native void Inverse_3();
  public void Inverse()
    { Inverse_3(); }

  private native void Translate_4(double id0,double id1,double id2);
  public void Translate(double id0,double id1,double id2)
    { Translate_4(id0,id1,id2); }

  private native void Translate_5(double id0[]);
  public void Translate(double id0[])
    { Translate_5(id0); }

  private native void RotateWXYZ_6(double id0,double id1,double id2,double id3);
  public void RotateWXYZ(double id0,double id1,double id2,double id3)
    { RotateWXYZ_6(id0,id1,id2,id3); }

  private native void RotateWXYZ_7(double id0,double id1[]);
  public void RotateWXYZ(double id0,double id1[])
    { RotateWXYZ_7(id0,id1); }

  private native void RotateX_8(double id0);
  public void RotateX(double id0)
    { RotateX_8(id0); }

  private native void RotateY_9(double id0);
  public void RotateY(double id0)
    { RotateY_9(id0); }

  private native void RotateZ_10(double id0);
  public void RotateZ(double id0)
    { RotateZ_10(id0); }

  private native void Scale_11(double id0,double id1,double id2);
  public void Scale(double id0,double id1,double id2)
    { Scale_11(id0,id1,id2); }

  private native void Scale_12(double id0[]);
  public void Scale(double id0[])
    { Scale_12(id0); }

  private native void SetMatrix_13(vtkMatrix4x4 id0);
  public void SetMatrix(vtkMatrix4x4 id0)
    { SetMatrix_13(id0); }

  private native void SetMatrix_14(double id0[]);
  public void SetMatrix(double id0[])
    { SetMatrix_14(id0); }

  private native void Concatenate_15(vtkMatrix4x4 id0);
  public void Concatenate(vtkMatrix4x4 id0)
    { Concatenate_15(id0); }

  private native void Concatenate_16(double id0[]);
  public void Concatenate(double id0[])
    { Concatenate_16(id0); }

  private native void Concatenate_17(vtkLinearTransform id0);
  public void Concatenate(vtkLinearTransform id0)
    { Concatenate_17(id0); }

  private native void PreMultiply_18();
  public void PreMultiply()
    { PreMultiply_18(); }

  private native void PostMultiply_19();
  public void PostMultiply()
    { PostMultiply_19(); }

  private native int GetNumberOfConcatenatedTransforms_20();
  public int GetNumberOfConcatenatedTransforms()
    { return GetNumberOfConcatenatedTransforms_20(); }

  private native long GetConcatenatedTransform_21(int id0);
  public vtkLinearTransform GetConcatenatedTransform(int id0) {
    long temp = GetConcatenatedTransform_21(id0);

    if (temp == 0) return null;
    return (vtkLinearTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetOrientation_22(double id0[]);
  public void GetOrientation(double id0[])
    { GetOrientation_22(id0); }

  private native double[] GetOrientation_23();
  public double[] GetOrientation()
    { return GetOrientation_23(); }

  private native void GetOrientation_24(double id0[],vtkMatrix4x4 id1);
  public void GetOrientation(double id0[],vtkMatrix4x4 id1)
    { GetOrientation_24(id0,id1); }

  private native void GetOrientationWXYZ_25(double id0[]);
  public void GetOrientationWXYZ(double id0[])
    { GetOrientationWXYZ_25(id0); }

  private native double[] GetOrientationWXYZ_26();
  public double[] GetOrientationWXYZ()
    { return GetOrientationWXYZ_26(); }

  private native void GetPosition_27(double id0[]);
  public void GetPosition(double id0[])
    { GetPosition_27(id0); }

  private native double[] GetPosition_28();
  public double[] GetPosition()
    { return GetPosition_28(); }

  private native void GetScale_29(double id0[]);
  public void GetScale(double id0[])
    { GetScale_29(id0); }

  private native double[] GetScale_30();
  public double[] GetScale()
    { return GetScale_30(); }

  private native void GetInverse_31(vtkMatrix4x4 id0);
  public void GetInverse(vtkMatrix4x4 id0)
    { GetInverse_31(id0); }

  private native void GetTranspose_32(vtkMatrix4x4 id0);
  public void GetTranspose(vtkMatrix4x4 id0)
    { GetTranspose_32(id0); }

  private native void SetInput_33(vtkLinearTransform id0);
  public void SetInput(vtkLinearTransform id0)
    { SetInput_33(id0); }

  private native long GetInput_34();
  public vtkLinearTransform GetInput() {
    long temp = GetInput_34();

    if (temp == 0) return null;
    return (vtkLinearTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetInverseFlag_35();
  public int GetInverseFlag()
    { return GetInverseFlag_35(); }

  private native void Push_36();
  public void Push()
    { Push_36(); }

  private native void Pop_37();
  public void Pop()
    { Pop_37(); }

  private native int CircuitCheck_38(vtkAbstractTransform id0);
  public int CircuitCheck(vtkAbstractTransform id0)
    { return CircuitCheck_38(id0); }

  private native long GetInverse_39();
  public vtkAbstractTransform GetInverse() {
    long temp = GetInverse_39();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MakeTransform_40();
  public vtkAbstractTransform MakeTransform() {
    long temp = MakeTransform_40();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_41();
  public int GetMTime()
    { return GetMTime_41(); }

  private native void MultiplyPoint_42(double id0[],double id1[]);
  public void MultiplyPoint(double id0[],double id1[])
    { MultiplyPoint_42(id0,id1); }

  public vtkTransform() { super(); }

  public vtkTransform(long id) { super(id); }
  public native long   VTKInit();

}
